@@ -68,7 +68,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 28 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:339  */
+#line 28 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:339  */
 
 
 #include "config.h"
@@ -155,7 +155,7 @@ extern int xpathyydebug;
 
 union YYSTYPE
 {
-#line 58 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:355  */
+#line 58 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:355  */
 
     Step::Axis axis;
     Step::NodeTest* nodeTest;
@@ -183,7 +183,7 @@ int xpathyyparse (WebCore::XPath::Parser* parser);
 #endif /* !YY_XPATHYY_DERIVEDSOURCES_WEBCORE_XPATHGRAMMAR_HPP_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
-#line 71 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:358  */
+#line 71 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:358  */
 
 
 static int xpathyylex(YYSTYPE* yylval) { return Parser::current()->lex(yylval); }
@@ -1345,7 +1345,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 120 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 120 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         parser->m_topExpr = (yyvsp[0].expr);
     }
@@ -1353,7 +1353,7 @@ yyreduce:
     break;
 
   case 3:
-#line 127 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 127 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.locationPath)->setAbsolute(false);
     }
@@ -1361,7 +1361,7 @@ yyreduce:
     break;
 
   case 4:
-#line 132 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 132 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.locationPath)->setAbsolute(true);
     }
@@ -1369,7 +1369,7 @@ yyreduce:
     break;
 
   case 5:
-#line 139 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 139 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.locationPath) = new LocationPath;
         parser->registerParseNode((yyval.locationPath));
@@ -1378,7 +1378,7 @@ yyreduce:
     break;
 
   case 6:
-#line 145 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 145 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.locationPath) = (yyvsp[0].locationPath);
     }
@@ -1386,7 +1386,7 @@ yyreduce:
     break;
 
   case 7:
-#line 150 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 150 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.locationPath) = (yyvsp[0].locationPath);
         (yyval.locationPath)->insertFirstStep((yyvsp[-1].step));
@@ -1396,7 +1396,7 @@ yyreduce:
     break;
 
   case 8:
-#line 159 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 159 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.locationPath) = new LocationPath;
         (yyval.locationPath)->appendStep((yyvsp[0].step));
@@ -1407,7 +1407,7 @@ yyreduce:
     break;
 
   case 9:
-#line 167 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 167 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.locationPath)->appendStep((yyvsp[0].step));
         parser->unregisterParseNode((yyvsp[0].step));
@@ -1416,7 +1416,7 @@ yyreduce:
     break;
 
   case 10:
-#line 173 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 173 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.locationPath)->appendStep((yyvsp[-1].step));
         (yyval.locationPath)->appendStep((yyvsp[0].step));
@@ -1427,7 +1427,7 @@ yyreduce:
     break;
 
   case 11:
-#line 183 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 183 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         if ((yyvsp[0].predList)) {
             (yyval.step) = new Step(Step::ChildAxis, *(yyvsp[-1].nodeTest), *(yyvsp[0].predList));
@@ -1441,7 +1441,7 @@ yyreduce:
     break;
 
   case 12:
-#line 194 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 194 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         String localName;
         String namespaceURI;
@@ -1462,7 +1462,7 @@ yyreduce:
     break;
 
   case 13:
-#line 212 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 212 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         if ((yyvsp[0].predList)) {
             (yyval.step) = new Step((yyvsp[-2].axis), *(yyvsp[-1].nodeTest), *(yyvsp[0].predList));
@@ -1476,7 +1476,7 @@ yyreduce:
     break;
 
   case 14:
-#line 223 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 223 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         String localName;
         String namespaceURI;
@@ -1497,7 +1497,7 @@ yyreduce:
     break;
 
   case 17:
-#line 247 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 247 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.axis) = Step::AttributeAxis;
     }
@@ -1505,7 +1505,7 @@ yyreduce:
     break;
 
   case 18:
-#line 254 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 254 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         if (*(yyvsp[-2].str) == "node")
             (yyval.nodeTest) = new Step::NodeTest(Step::NodeTest::AnyNodeTest);
@@ -1521,7 +1521,7 @@ yyreduce:
     break;
 
   case 19:
-#line 267 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 267 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.nodeTest) = new Step::NodeTest(Step::NodeTest::ProcessingInstructionNodeTest);
         parser->deleteString((yyvsp[-2].str));
@@ -1531,7 +1531,7 @@ yyreduce:
     break;
 
   case 20:
-#line 274 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 274 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.nodeTest) = new Step::NodeTest(Step::NodeTest::ProcessingInstructionNodeTest, (yyvsp[-1].str)->stripWhiteSpace());
         parser->deleteString((yyvsp[-3].str));
@@ -1542,7 +1542,7 @@ yyreduce:
     break;
 
   case 21:
-#line 284 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 284 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.predList) = 0;
     }
@@ -1550,7 +1550,7 @@ yyreduce:
     break;
 
   case 23:
-#line 293 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 293 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.predList) = new Vector<Predicate*>;
         (yyval.predList)->append(new Predicate((yyvsp[0].expr)));
@@ -1561,7 +1561,7 @@ yyreduce:
     break;
 
   case 24:
-#line 301 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 301 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.predList)->append(new Predicate((yyvsp[0].expr)));
         parser->unregisterParseNode((yyvsp[0].expr));
@@ -1570,7 +1570,7 @@ yyreduce:
     break;
 
   case 25:
-#line 309 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 309 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = (yyvsp[-1].expr);
     }
@@ -1578,7 +1578,7 @@ yyreduce:
     break;
 
   case 26:
-#line 316 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 316 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.step) = new Step(Step::DescendantOrSelfAxis, Step::NodeTest(Step::NodeTest::AnyNodeTest));
         parser->registerParseNode((yyval.step));
@@ -1587,7 +1587,7 @@ yyreduce:
     break;
 
   case 27:
-#line 324 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 324 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.step) = new Step(Step::SelfAxis, Step::NodeTest(Step::NodeTest::AnyNodeTest));
         parser->registerParseNode((yyval.step));
@@ -1596,7 +1596,7 @@ yyreduce:
     break;
 
   case 28:
-#line 330 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 330 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.step) = new Step(Step::ParentAxis, Step::NodeTest(Step::NodeTest::AnyNodeTest));
         parser->registerParseNode((yyval.step));
@@ -1605,7 +1605,7 @@ yyreduce:
     break;
 
   case 29:
-#line 338 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 338 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new VariableReference(*(yyvsp[0].str));
         parser->deleteString((yyvsp[0].str));
@@ -1615,7 +1615,7 @@ yyreduce:
     break;
 
   case 30:
-#line 345 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 345 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = (yyvsp[-1].expr);
     }
@@ -1623,7 +1623,7 @@ yyreduce:
     break;
 
   case 31:
-#line 350 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 350 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new StringExpression(*(yyvsp[0].str));
         parser->deleteString((yyvsp[0].str));
@@ -1633,7 +1633,7 @@ yyreduce:
     break;
 
   case 32:
-#line 357 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 357 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new Number((yyvsp[0].str)->toDouble());
         parser->deleteString((yyvsp[0].str));
@@ -1643,7 +1643,7 @@ yyreduce:
     break;
 
   case 34:
-#line 368 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 368 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = createFunction(*(yyvsp[-2].str));
         if (!(yyval.expr))
@@ -1655,7 +1655,7 @@ yyreduce:
     break;
 
   case 35:
-#line 377 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 377 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = createFunction(*(yyvsp[-3].str), *(yyvsp[-1].argList));
         if (!(yyval.expr))
@@ -1668,7 +1668,7 @@ yyreduce:
     break;
 
   case 36:
-#line 389 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 389 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.argList) = new Vector<Expression*>;
         (yyval.argList)->append((yyvsp[0].expr));
@@ -1679,7 +1679,7 @@ yyreduce:
     break;
 
   case 37:
-#line 397 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 397 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.argList)->append((yyvsp[0].expr));
         parser->unregisterParseNode((yyvsp[0].expr));
@@ -1688,7 +1688,7 @@ yyreduce:
     break;
 
   case 40:
-#line 411 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 411 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new Union;
         (yyval.expr)->addSubExpression((yyvsp[-2].expr));
@@ -1701,7 +1701,7 @@ yyreduce:
     break;
 
   case 41:
-#line 423 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 423 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = (yyvsp[0].locationPath);
     }
@@ -1709,7 +1709,7 @@ yyreduce:
     break;
 
   case 43:
-#line 430 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 430 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyvsp[0].locationPath)->setAbsolute(true);
         (yyval.expr) = new Path(static_cast<Filter*>((yyvsp[-2].expr)), (yyvsp[0].locationPath));
@@ -1721,7 +1721,7 @@ yyreduce:
     break;
 
   case 44:
-#line 439 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 439 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyvsp[0].locationPath)->insertFirstStep((yyvsp[-1].step));
         (yyvsp[0].locationPath)->setAbsolute(true);
@@ -1735,7 +1735,7 @@ yyreduce:
     break;
 
   case 46:
-#line 454 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 454 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new Filter((yyvsp[-1].expr), *(yyvsp[0].predList));
         parser->unregisterParseNode((yyvsp[-1].expr));
@@ -1746,7 +1746,7 @@ yyreduce:
     break;
 
   case 48:
-#line 466 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 466 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new LogicalOp(LogicalOp::OP_Or, (yyvsp[-2].expr), (yyvsp[0].expr));
         parser->unregisterParseNode((yyvsp[-2].expr));
@@ -1757,7 +1757,7 @@ yyreduce:
     break;
 
   case 50:
-#line 478 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 478 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new LogicalOp(LogicalOp::OP_And, (yyvsp[-2].expr), (yyvsp[0].expr));
         parser->unregisterParseNode((yyvsp[-2].expr));
@@ -1768,7 +1768,7 @@ yyreduce:
     break;
 
   case 52:
-#line 490 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 490 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new EqTestOp((yyvsp[-1].eqop), (yyvsp[-2].expr), (yyvsp[0].expr));
         parser->unregisterParseNode((yyvsp[-2].expr));
@@ -1779,7 +1779,7 @@ yyreduce:
     break;
 
   case 54:
-#line 502 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 502 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new EqTestOp((yyvsp[-1].eqop), (yyvsp[-2].expr), (yyvsp[0].expr));
         parser->unregisterParseNode((yyvsp[-2].expr));
@@ -1790,7 +1790,7 @@ yyreduce:
     break;
 
   case 56:
-#line 514 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 514 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new NumericOp(NumericOp::OP_Add, (yyvsp[-2].expr), (yyvsp[0].expr));
         parser->unregisterParseNode((yyvsp[-2].expr));
@@ -1801,7 +1801,7 @@ yyreduce:
     break;
 
   case 57:
-#line 522 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 522 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new NumericOp(NumericOp::OP_Sub, (yyvsp[-2].expr), (yyvsp[0].expr));
         parser->unregisterParseNode((yyvsp[-2].expr));
@@ -1812,7 +1812,7 @@ yyreduce:
     break;
 
   case 59:
-#line 534 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 534 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new NumericOp((yyvsp[-1].numop), (yyvsp[-2].expr), (yyvsp[0].expr));
         parser->unregisterParseNode((yyvsp[-2].expr));
@@ -1823,7 +1823,7 @@ yyreduce:
     break;
 
   case 61:
-#line 546 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
+#line 546 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1646  */
     {
         (yyval.expr) = new Negative;
         (yyval.expr)->addSubExpression((yyvsp[0].expr));
@@ -2062,5 +2062,5 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 554 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1906  */
+#line 554 "/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebCore/xml/XPathGrammar.y" /* yacc.c:1906  */
 
