@@ -50,7 +50,7 @@ extern "C" {
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:ENUM,INT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:1) */
+/* BOOLEAN:ENUM,INT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:1) */
 void
 webkit_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
                                   GValue       *return_value G_GNUC_UNUSED,
@@ -63,9 +63,9 @@ webkit_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
                                                       gint         arg_1,
                                                       gint         arg_2,
                                                       gpointer     data2);
-  register GMarshalFunc_BOOLEAN__ENUM_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__ENUM_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -91,7 +91,7 @@ webkit_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:INT,INT,STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:2) */
+/* BOOLEAN:INT,INT,STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:2) */
 void
 webkit_marshal_BOOLEAN__INT_INT_STRING (GClosure     *closure,
                                         GValue       *return_value G_GNUC_UNUSED,
@@ -105,9 +105,9 @@ webkit_marshal_BOOLEAN__INT_INT_STRING (GClosure     *closure,
                                                             gint         arg_2,
                                                             gpointer     arg_3,
                                                             gpointer     data2);
-  register GMarshalFunc_BOOLEAN__INT_INT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__INT_INT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -134,7 +134,7 @@ webkit_marshal_BOOLEAN__INT_INT_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:3) */
+/* BOOLEAN:OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:3) */
 void
 webkit_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                 GValue       *return_value G_GNUC_UNUSED,
@@ -146,9 +146,9 @@ webkit_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT) (gpointer     data1,
                                                     gpointer     arg_1,
                                                     gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -173,7 +173,7 @@ webkit_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:4) */
+/* BOOLEAN:OBJECT,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:4) */
 void
 webkit_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                        GValue       *return_value G_GNUC_UNUSED,
@@ -186,9 +186,9 @@ webkit_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                            gpointer     arg_1,
                                                            gpointer     arg_2,
                                                            gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -214,7 +214,7 @@ webkit_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,OBJECT,BOOLEAN (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:5) */
+/* BOOLEAN:OBJECT,OBJECT,BOOLEAN (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:5) */
 void
 webkit_marshal_BOOLEAN__OBJECT_OBJECT_BOOLEAN (GClosure     *closure,
                                                GValue       *return_value G_GNUC_UNUSED,
@@ -228,9 +228,9 @@ webkit_marshal_BOOLEAN__OBJECT_OBJECT_BOOLEAN (GClosure     *closure,
                                                                    gpointer     arg_2,
                                                                    gboolean     arg_3,
                                                                    gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_OBJECT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_OBJECT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -257,7 +257,7 @@ webkit_marshal_BOOLEAN__OBJECT_OBJECT_BOOLEAN (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,OBJECT,ENUM (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:6) */
+/* BOOLEAN:OBJECT,OBJECT,ENUM (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:6) */
 void
 webkit_marshal_BOOLEAN__OBJECT_OBJECT_ENUM (GClosure     *closure,
                                             GValue       *return_value G_GNUC_UNUSED,
@@ -271,9 +271,9 @@ webkit_marshal_BOOLEAN__OBJECT_OBJECT_ENUM (GClosure     *closure,
                                                                 gpointer     arg_2,
                                                                 gint         arg_3,
                                                                 gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_OBJECT_ENUM callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_OBJECT_ENUM callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -300,7 +300,7 @@ webkit_marshal_BOOLEAN__OBJECT_OBJECT_ENUM (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,OBJECT,ENUM,BOOLEAN (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:7) */
+/* BOOLEAN:OBJECT,OBJECT,ENUM,BOOLEAN (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:7) */
 void
 webkit_marshal_BOOLEAN__OBJECT_OBJECT_ENUM_BOOLEAN (GClosure     *closure,
                                                     GValue       *return_value G_GNUC_UNUSED,
@@ -315,9 +315,9 @@ webkit_marshal_BOOLEAN__OBJECT_OBJECT_ENUM_BOOLEAN (GClosure     *closure,
                                                                         gint         arg_3,
                                                                         gboolean     arg_4,
                                                                         gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_OBJECT_ENUM_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_OBJECT_ENUM_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -345,7 +345,7 @@ webkit_marshal_BOOLEAN__OBJECT_OBJECT_ENUM_BOOLEAN (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,OBJECT,OBJECT,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:8) */
+/* BOOLEAN:OBJECT,OBJECT,OBJECT,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:8) */
 void
 webkit_marshal_BOOLEAN__OBJECT_OBJECT_OBJECT_OBJECT (GClosure     *closure,
                                                      GValue       *return_value G_GNUC_UNUSED,
@@ -360,9 +360,9 @@ webkit_marshal_BOOLEAN__OBJECT_OBJECT_OBJECT_OBJECT (GClosure     *closure,
                                                                          gpointer     arg_3,
                                                                          gpointer     arg_4,
                                                                          gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_OBJECT_OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_OBJECT_OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -390,7 +390,7 @@ webkit_marshal_BOOLEAN__OBJECT_OBJECT_OBJECT_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,OBJECT,STRING,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:9) */
+/* BOOLEAN:OBJECT,OBJECT,STRING,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:9) */
 void
 webkit_marshal_BOOLEAN__OBJECT_OBJECT_STRING_OBJECT (GClosure     *closure,
                                                      GValue       *return_value G_GNUC_UNUSED,
@@ -405,9 +405,9 @@ webkit_marshal_BOOLEAN__OBJECT_OBJECT_STRING_OBJECT (GClosure     *closure,
                                                                          gpointer     arg_3,
                                                                          gpointer     arg_4,
                                                                          gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_OBJECT_STRING_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_OBJECT_STRING_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -435,7 +435,7 @@ webkit_marshal_BOOLEAN__OBJECT_OBJECT_STRING_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:10) */
+/* BOOLEAN:OBJECT,STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:10) */
 void
 webkit_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
                                        GValue       *return_value G_GNUC_UNUSED,
@@ -448,9 +448,9 @@ webkit_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
                                                            gpointer     arg_1,
                                                            gpointer     arg_2,
                                                            gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -476,7 +476,7 @@ webkit_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,STRING,BOXED (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:11) */
+/* BOOLEAN:OBJECT,STRING,BOXED (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:11) */
 void
 webkit_marshal_BOOLEAN__OBJECT_STRING_BOXED (GClosure     *closure,
                                              GValue       *return_value G_GNUC_UNUSED,
@@ -490,9 +490,9 @@ webkit_marshal_BOOLEAN__OBJECT_STRING_BOXED (GClosure     *closure,
                                                                  gpointer     arg_2,
                                                                  gpointer     arg_3,
                                                                  gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_STRING_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_STRING_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -519,7 +519,7 @@ webkit_marshal_BOOLEAN__OBJECT_STRING_BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,STRING,POINTER (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:12) */
+/* BOOLEAN:OBJECT,STRING,POINTER (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:12) */
 void
 webkit_marshal_BOOLEAN__OBJECT_STRING_POINTER (GClosure     *closure,
                                                GValue       *return_value G_GNUC_UNUSED,
@@ -533,9 +533,9 @@ webkit_marshal_BOOLEAN__OBJECT_STRING_POINTER (GClosure     *closure,
                                                                    gpointer     arg_2,
                                                                    gpointer     arg_3,
                                                                    gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_STRING_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_STRING_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -562,7 +562,7 @@ webkit_marshal_BOOLEAN__OBJECT_STRING_POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,STRING,STRING,STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:13) */
+/* BOOLEAN:OBJECT,STRING,STRING,STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:13) */
 void
 webkit_marshal_BOOLEAN__OBJECT_STRING_STRING_STRING (GClosure     *closure,
                                                      GValue       *return_value G_GNUC_UNUSED,
@@ -577,9 +577,9 @@ webkit_marshal_BOOLEAN__OBJECT_STRING_STRING_STRING (GClosure     *closure,
                                                                          gpointer     arg_3,
                                                                          gpointer     arg_4,
                                                                          gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_STRING_STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_STRING_STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -607,7 +607,7 @@ webkit_marshal_BOOLEAN__OBJECT_STRING_STRING_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,INT,STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:14) */
+/* BOOLEAN:STRING,INT,STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:14) */
 void
 webkit_marshal_BOOLEAN__STRING_INT_STRING (GClosure     *closure,
                                            GValue       *return_value G_GNUC_UNUSED,
@@ -621,9 +621,9 @@ webkit_marshal_BOOLEAN__STRING_INT_STRING (GClosure     *closure,
                                                                gint         arg_2,
                                                                gpointer     arg_3,
                                                                gpointer     data2);
-  register GMarshalFunc_BOOLEAN__STRING_INT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__STRING_INT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -650,7 +650,7 @@ webkit_marshal_BOOLEAN__STRING_INT_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,OBJECT,ENUM (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:15) */
+/* BOOLEAN:STRING,OBJECT,ENUM (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:15) */
 void
 webkit_marshal_BOOLEAN__STRING_OBJECT_ENUM (GClosure     *closure,
                                             GValue       *return_value G_GNUC_UNUSED,
@@ -664,9 +664,9 @@ webkit_marshal_BOOLEAN__STRING_OBJECT_ENUM (GClosure     *closure,
                                                                 gpointer     arg_2,
                                                                 gint         arg_3,
                                                                 gpointer     data2);
-  register GMarshalFunc_BOOLEAN__STRING_OBJECT_ENUM callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__STRING_OBJECT_ENUM callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -693,7 +693,7 @@ webkit_marshal_BOOLEAN__STRING_OBJECT_ENUM (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:16) */
+/* BOOLEAN:VOID (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:16) */
 void
 webkit_marshal_BOOLEAN__VOID (GClosure     *closure,
                               GValue       *return_value G_GNUC_UNUSED,
@@ -704,9 +704,9 @@ webkit_marshal_BOOLEAN__VOID (GClosure     *closure,
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
                                                   gpointer     data2);
-  register GMarshalFunc_BOOLEAN__VOID callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__VOID callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -730,7 +730,7 @@ webkit_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* ENUM:OBJECT,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:17) */
+/* ENUM:OBJECT,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:17) */
 void
 webkit_marshal_ENUM__OBJECT_OBJECT (GClosure     *closure,
                                     GValue       *return_value G_GNUC_UNUSED,
@@ -743,9 +743,9 @@ webkit_marshal_ENUM__OBJECT_OBJECT (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_ENUM__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_ENUM__OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gint v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -771,7 +771,7 @@ webkit_marshal_ENUM__OBJECT_OBJECT (GClosure     *closure,
   g_value_set_enum (return_value, v_return);
 }
 
-/* OBJECT:OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:18) */
+/* OBJECT:OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:18) */
 void
 webkit_marshal_OBJECT__OBJECT (GClosure     *closure,
                                GValue       *return_value G_GNUC_UNUSED,
@@ -783,9 +783,9 @@ webkit_marshal_OBJECT__OBJECT (GClosure     *closure,
   typedef GObject* (*GMarshalFunc_OBJECT__OBJECT) (gpointer     data1,
                                                    gpointer     arg_1,
                                                    gpointer     data2);
-  register GMarshalFunc_OBJECT__OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_OBJECT__OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   GObject* v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -810,7 +810,7 @@ webkit_marshal_OBJECT__OBJECT (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* OBJECT:STRING,STRING,POINTER (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:19) */
+/* OBJECT:STRING,STRING,POINTER (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:19) */
 void
 webkit_marshal_OBJECT__STRING_STRING_POINTER (GClosure     *closure,
                                               GValue       *return_value G_GNUC_UNUSED,
@@ -824,9 +824,9 @@ webkit_marshal_OBJECT__STRING_STRING_POINTER (GClosure     *closure,
                                                                   gpointer     arg_2,
                                                                   gpointer     arg_3,
                                                                   gpointer     data2);
-  register GMarshalFunc_OBJECT__STRING_STRING_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_OBJECT__STRING_STRING_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   GObject* v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -853,7 +853,7 @@ webkit_marshal_OBJECT__STRING_STRING_POINTER (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* OBJECT:VOID (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:20) */
+/* OBJECT:VOID (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:20) */
 void
 webkit_marshal_OBJECT__VOID (GClosure     *closure,
                              GValue       *return_value G_GNUC_UNUSED,
@@ -864,9 +864,9 @@ webkit_marshal_OBJECT__VOID (GClosure     *closure,
 {
   typedef GObject* (*GMarshalFunc_OBJECT__VOID) (gpointer     data1,
                                                  gpointer     data2);
-  register GMarshalFunc_OBJECT__VOID callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_OBJECT__VOID callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   GObject* v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -890,7 +890,7 @@ webkit_marshal_OBJECT__VOID (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* VOID:OBJECT,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:21) */
+/* VOID:OBJECT,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:21) */
 void
 webkit_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                     GValue       *return_value G_GNUC_UNUSED,
@@ -903,9 +903,9 @@ webkit_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -927,7 +927,7 @@ webkit_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT,INT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:22) */
+/* VOID:OBJECT,OBJECT,INT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:22) */
 void
 webkit_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
                                         GValue       *return_value G_GNUC_UNUSED,
@@ -941,9 +941,9 @@ webkit_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
                                                         gpointer     arg_2,
                                                         gint         arg_3,
                                                         gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -966,7 +966,7 @@ webkit_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:23) */
+/* VOID:OBJECT,OBJECT,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:23) */
 void
 webkit_marshal_VOID__OBJECT_OBJECT_OBJECT (GClosure     *closure,
                                            GValue       *return_value G_GNUC_UNUSED,
@@ -980,9 +980,9 @@ webkit_marshal_VOID__OBJECT_OBJECT_OBJECT (GClosure     *closure,
                                                            gpointer     arg_2,
                                                            gpointer     arg_3,
                                                            gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -1005,7 +1005,7 @@ webkit_marshal_VOID__OBJECT_OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT,POINTER (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:24) */
+/* VOID:OBJECT,OBJECT,POINTER (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:24) */
 void
 webkit_marshal_VOID__OBJECT_OBJECT_POINTER (GClosure     *closure,
                                             GValue       *return_value G_GNUC_UNUSED,
@@ -1019,9 +1019,9 @@ webkit_marshal_VOID__OBJECT_OBJECT_POINTER (GClosure     *closure,
                                                             gpointer     arg_2,
                                                             gpointer     arg_3,
                                                             gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -1044,7 +1044,7 @@ webkit_marshal_VOID__OBJECT_OBJECT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT,BOXED (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:25) */
+/* VOID:OBJECT,OBJECT,BOXED (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:25) */
 void
 webkit_marshal_VOID__OBJECT_OBJECT_BOXED (GClosure     *closure,
                                           GValue       *return_value G_GNUC_UNUSED,
@@ -1058,9 +1058,9 @@ webkit_marshal_VOID__OBJECT_OBJECT_BOXED (GClosure     *closure,
                                                           gpointer     arg_2,
                                                           gpointer     arg_3,
                                                           gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -1083,7 +1083,7 @@ webkit_marshal_VOID__OBJECT_OBJECT_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT,OBJECT,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:26) */
+/* VOID:OBJECT,OBJECT,OBJECT,OBJECT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:26) */
 void
 webkit_marshal_VOID__OBJECT_OBJECT_OBJECT_OBJECT (GClosure     *closure,
                                                   GValue       *return_value G_GNUC_UNUSED,
@@ -1098,9 +1098,9 @@ webkit_marshal_VOID__OBJECT_OBJECT_OBJECT_OBJECT (GClosure     *closure,
                                                                   gpointer     arg_3,
                                                                   gpointer     arg_4,
                                                                   gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT_OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT_OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -1124,7 +1124,7 @@ webkit_marshal_VOID__OBJECT_OBJECT_OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,POINTER,POINTER (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:27) */
+/* VOID:OBJECT,POINTER,POINTER (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:27) */
 void
 webkit_marshal_VOID__OBJECT_POINTER_POINTER (GClosure     *closure,
                                              GValue       *return_value G_GNUC_UNUSED,
@@ -1138,9 +1138,9 @@ webkit_marshal_VOID__OBJECT_POINTER_POINTER (GClosure     *closure,
                                                              gpointer     arg_2,
                                                              gpointer     arg_3,
                                                              gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_POINTER_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_POINTER_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -1163,7 +1163,7 @@ webkit_marshal_VOID__OBJECT_POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,INT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:28) */
+/* VOID:OBJECT,INT (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:28) */
 void
 webkit_marshal_VOID__OBJECT_INT (GClosure     *closure,
                                  GValue       *return_value G_GNUC_UNUSED,
@@ -1176,9 +1176,9 @@ webkit_marshal_VOID__OBJECT_INT (GClosure     *closure,
                                                  gpointer     arg_1,
                                                  gint         arg_2,
                                                  gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -1200,7 +1200,7 @@ webkit_marshal_VOID__OBJECT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,POINTER (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:29) */
+/* VOID:OBJECT,POINTER (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:29) */
 void
 webkit_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                      GValue       *return_value G_GNUC_UNUSED,
@@ -1213,9 +1213,9 @@ webkit_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                      gpointer     arg_1,
                                                      gpointer     arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -1237,7 +1237,7 @@ webkit_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:30) */
+/* VOID:OBJECT,STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:30) */
 void
 webkit_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                     GValue       *return_value G_GNUC_UNUSED,
@@ -1250,9 +1250,9 @@ webkit_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -1274,9 +1274,9 @@ webkit_marshal_VOID__OBJECT_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:31) */
+/* VOID:STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:31) */
 
-/* VOID:STRING,STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-4.x86_64/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:32) */
+/* VOID:STRING,STRING (/usr/src/ports/webkitgtk/webkitgtk-2.0.4-5.i686/src/webkitgtk-2.0.4/Source/WebKit/gtk/webkitmarshal.list:32) */
 void
 webkit_marshal_VOID__STRING_STRING (GClosure     *closure,
                                     GValue       *return_value G_GNUC_UNUSED,
@@ -1289,9 +1289,9 @@ webkit_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
